@@ -38,5 +38,5 @@ print('#'*60+ ' Parameters for %s '%hello_utils.get_fleet_id()+'#'*60)
 print ("{:<70} {:<70} {:<30}".format('Origin','Parameter','Value'))
 print('-'*170)
 for param in rep.keys():
-    print("{:<70} {:<70} {:<30}".format(rep[param][1], param, rep[param][0] ))
+    print("{:<70} {:<70} {:<30}".format(str(rep[param][1]), param, str(rep[param][0] )))
 
