@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+from __future__ import print_function
 import stretch_body.wrist_yaw as wrist_yaw
 import argparse
 import stretch_body.hello_utils as hu
@@ -8,6 +9,7 @@ parser=argparse.ArgumentParser(description='Calibrate the wrist_yaw position by
 args=parser.parse_args()
 
 g=wrist_yaw.WristYaw()
-g.startup()
+if not g.startup():
+    exit()
 g.home()
 g.stop()
